% constant.m
% This script states the constants used to solve the model.

% Global constant variables that are used in different scripts/functions
global GASCONST Ncomp MMASS Aq Eq beta Tref Hr kref ...
    EA AXref dHX CP LAMBDA B S sumny
 
% General constants
%-------------------------------------------------------------------
GASCONST  = 8.3145e3;   % Gas constant                   [J/kmole.K]
Ncomp     = 6;          % Number of components                   [-]

% Component molar mass (from HYSYS)                       [kg/kmole]
%-------------------------------------------------------------------
MMASS(1) = 16.0429000854492;         % Molar mass of CH4
MMASS(2) = 28.0109004974365;         % Molar mass of CO
MMASS(3) = 44.0097007751465;         % Molar mass of CO2
MMASS(4) = 2.01600003242493;         % Molar mass of H2
MMASS(5) = 18.0151004791260;         % Molar mass of H2O
MMASS(6) = 28.0130004882813;         % Molar mass of N2

% Equilibrium constant coefficients
%-------------------------------------------------------------------
Aq   = 11.2561956932934;    % Pre-exp. factor coef.    [bar^-2 K^-1]
Eq   = 18530.1820006599;    % Activation energy coef.      [kJ/kmol]
beta = -4.84168695852905;   % Temperature coef.                  [-]

% Pre-exponential factor for the rate constant
%-------------------------------------------------------------------
Tref = 555;       % Reference temperature                        [K]  
kref = 3.46e-4;   % Rate constant factor         [kmole/bar.kgcat.s]

% Activation energy coefficient for reaction               [J/kmole]
%-------------------------------------------------------------------
EA = 77.5e6;      % Activation energy

% Pre-exponential factor for the adsorption constant      [bar^-0.5]
%-------------------------------------------------------------------
AXref(1) = 0.50;  % Factor of OH                     
AXref(2) = 0.44;  % Factor of H2                     
AXref(3) = 0.88;  % Factor of MIX                    

% Adsorption enthalpy coefficients                         [J/kmole]
%-------------------------------------------------------------------
dHX(1) = 22.4e6;    % Adsorption enthalpy of OH
dHX(2) = -6.2e6;    % Adsorption enthalpy of H2
dHX(3) = -10.0e6;   % Adsorption enthalpy of MIX

% Reaction enthalpy coefficients
%-------------------------------------------------------------------
Hr(1)  = -1.47040e2;      % 1st coefficient                [J/kmole]
Hr(2)  = -6.59812e-2;     % 2nd coefficient              [J/kmole.K]
Hr(3)  = 2.31450e-5;      % 3rd coefficient            [J/kmole.K^2]
Hr(4)  = 1.51675e-10;     % 4th coefficient            [J/kmole.K^3]

% Component heat capacity coefficients      
%-------------------------------------------------------------------
CP(1,1) = 1.925e4;        % 1st coefficient for CH4      [J/kmole.K]
CP(1,2) = 5.213e1;        % 2nd coefficient for CH4    [J/kmole.K^2]
CP(1,3) = 1.197e-2;       % 3rd coefficient for CH4    [J/kmole.K^3]
CP(1,4) = -1.132e-5;      % 4th coefficient for CH4    [J/kmole.K^4]

CP(2,1) = 3.087e4;        % 1st coefficient for CO       [J/kmole.K]
CP(2,2) = -1.285e1;       % 2nd coefficient for CO     [J/kmole.K^2]
CP(2,3) = 2.789e-2;       % 3rd coefficient for CO     [J/kmole.K^3]
CP(2,4) = -1.272e-5;      % 4th coefficient for CO     [J/kmole.K^4]

CP(3,1) = 1.980e4;        % 1st coefficient for CO2      [J/kmole.K]
CP(3,2) = 7.344e1;        % 2nd coefficient for CO2    [J/kmole.K^2]
CP(3,3) = -5.602e-2;      % 3rd coefficient for CO2    [J/kmole.K^3]
CP(3,4) = 1.715e-5;       % 4th coefficient for CO2    [J/kmole.K^4]

CP(4,1) = 2.714e4;        % 1st coefficient for H2        [J/kmole.K]
CP(4,2) = 0.9274e1;       % 2nd coefficient for H2      [J/kmole.K^2]
CP(4,3) = -1.381e-2;      % 3rd coefficient for H2      [J/kmole.K^3]
CP(4,4) = 0.7645e-5;      % 4th coefficient for H2      [J/kmole.K^4]

CP(5,1) = 3.224e4;        % 1st coefficient for H2O       [J/kmole.K]
CP(5,2) = 0.1924e1;       % 2nd coefficient for H2O     [J/kmole.K^2]
CP(5,3) = 1.055e-2;       % 3rd coefficient for H2O     [J/kmole.K^3]
CP(5,4) = 0.3596e-5;      % 4th coefficient for H2O     [J/kmole.K^4]

CP(6,1) = 3.115e4;        % 1st coefficient for N2        [J/kmole.K]
CP(6,2) = -1.357e1;       % 2nd coefficient for N2      [J/kmole.K^2]
CP(6,3) = 2.680e-2;       % 3rd coefficient for N2      [J/kmole.K^3]
CP(6,4) = -1.168e-5;      % 4th coefficient for N2      [J/kmole.K^4]

% Component conductivity coefficients
%-------------------------------------------------------------------
LAMBDA(1,1) = -1.869e-3;    % 1st coefficient for CH4         [W/m.K]
LAMBDA(1,2) = 8.727e-5;     % 2nd coefficient for CH4       [W/m.K^2]
LAMBDA(1,3) = 1.179e-7;     % 3rd coefficient for CH4       [W/m.K^3]
LAMBDA(1,4) = -3.614e-11;   % 4th coefficient for CH4       [W/m.K^4]

LAMBDA(2,1) = 5.067e-4;     % 1st coefficient for CO          [W/m.K]
LAMBDA(2,2) = 9.1025e-5;    % 2nd coefficient for CO        [W/m.K^2]
LAMBDA(2,3) = -3.524e-8;    % 3rd coefficient for CO        [W/m.K^3]
LAMBDA(2,4) = 8.199e-12;    % 4th coefficient for CO        [W/m.K^4]

LAMBDA(3,1) = -7.215e-3;    % 1st coefficient for CO2         [W/m.K]
LAMBDA(3,2) = 8.015e-5;     % 2nd coefficient for CO2       [W/m.K^2]
LAMBDA(3,3) = 5.477e-9;     % 3rd coefficient for CO2       [W/m.K^3]
LAMBDA(3,4) = -1.053e-11;   % 4th coefficient for CO2       [W/m.K^4]

LAMBDA(4,1) = 8.099e-3;     % 1st coefficient for H2          [W/m.K]
LAMBDA(4,2) = 6.689e-4;     % 2nd coefficient for H2        [W/m.K^2]
LAMBDA(4,3) = -4.158e-7;    % 3rd coefficient for H2        [W/m.K^3]
LAMBDA(4,4) = 1.562e-10;    % 4th coefficient for H2        [W/m.K^4]

LAMBDA(5,1) = 7.341e-3;     % 1st coefficient for H2O         [W/m.K]
LAMBDA(5,2) = -1.013e-5;    % 2nd coefficient for H2O       [W/m.K^2]
LAMBDA(5,3) = 1.801e-7;     % 3rd coefficient for H2O       [W/m.K^3]
LAMBDA(5,4) = -9.100e-11;   % 4th coefficient for H2O       [W/m.K^4]

LAMBDA(6,1) = 3.919e-4;     % 1st coefficient for N2          [W/m.K]
LAMBDA(6,2) = 9.966e-5;     % 2nd coefficient for N2        [W/m.K^2]
LAMBDA(6,3) = -5.067e-8;    % 3rd coefficient for N2        [W/m.K^3]
LAMBDA(6,4) = 1.504e-11;    % 4th coefficient for N2        [W/m.K^4]

% Component viscosity coefficients
%-------------------------------------------------------------------
B(1) = 1.00e-6;           % Coefficient for CH4       [kg/m.s.K^0.5]
B(2) = 1.50e-6;           % Coefficient for CO        [kg/m.s.K^0.5]
B(3) = 1.50e-6;           % Coefficient for CO2       [kg/m.s.K^0.5]
B(4) = 0.65e-6;           % Coefficient for H2        [kg/m.s.K^0.5]
B(5) = 1.74e-6;           % Coefficient for H2O       [kg/m.s.K^0.5]
B(6) = 1.40e-6;           % Coefficient for N2        [kg/m.s.K^0.5]

S(1) = 168;               % Coefficient for CH4                  [K]
S(2) = 220;               % Coefficient for CO                   [K]
S(3) = 220;               % Coefficient for CO2                  [K]
S(4) = 67;                % Coefficient for H2                   [K]
S(5) = 625;               % Coefficient for H2O                  [K]
S(6) = 108;               % Coefficient for N2                   [K]

% Special diffusion volumes coefficients (from Sinnott2009)      [-]
%-------------------------------------------------------------------
sumny(1) = 24.42;         % Coefficient for CH4
sumny(2) = 18.90;         % Coefficient for CO
sumny(3) = 26.90;         % Coefficient for CO2
sumny(4) = 7.07;          % Coefficient for H2
sumny(5) = 12.70;         % Coefficient for H2O
sumny(6) = 17.90;         % Coefficient for N2
