% plotting.m
% This script is imported in the main.m script for plotting the parameters:
% temperature, velocity, pressure, flowrate, component mole fractions,
% reaction rate, heat flowrate and heat of reaction.

switch dataplots

  case 1 % CH4 molefraction
    surf(r*100,z,y(:,:,1)*100)
    view(az, el);                                   
    xlabel('Tube radius, $R$ [cm]', 'interpreter','latex', 'fontsize',12)
    xticks(0:0.25:RADIUSi*100)
    xtickformat('%.2f')
    ylabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',12)
    ylim([0, LENGTH+0.5])
    yticks(0:1:LENGTH)
    zlabel('CH$_4$ mole fraction, $y_{CH4}$ [$\%$]', 'interpreter','latex', 'fontsize',12)
    ztickformat('%.0f')
    filename = 'MoleFractionProfileCH4';            
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
  case 2 % CO molefraction
    surf(r*100,z,y(:,:,2)*100) 
    view(az, el);                                   
    xlabel('Tube radius, $R$ [cm]', 'interpreter','latex', 'fontsize',12)
    xticks(0:0.25:RADIUSi*100)
    xtickformat('%.2f')
    ylabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',12)
    ylim([0, LENGTH+0.5])
    yticks(0:1:LENGTH)
    zlabel('CO mole fraction, $y_{CO}$ [$\%$]', 'interpreter','latex', 'fontsize',12)
    zlim([-0.05, 0.1])
    ztickformat('%.1f')
    filename = 'MoleFractionProfileCO';            
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
  case 3 % CO2 molefraction
    surf(r*100,z,y(:,:,3)*100)
    view(az, el);                                    
    xlabel('Tube radius, $R$ [cm]', 'interpreter','latex', 'fontsize',12)
    xticks(0:0.25:RADIUSi*100)
    xtickformat('%.2f')
    ylabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',12)
    ylim([0, LENGTH+0.5])
    yticks(0:1:LENGTH)
    zlabel('CO$_2$ mole fraction, $y_{CO2}$ [$\%$]', 'interpreter','latex', 'fontsize',12)
    ztickformat('%.0f')
    filename = 'MoleFractionProfileCO2';             
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
  case 4 % H2 molefraction
    surf(r*100,z,y(:,:,4)*100)
    view(az, el);                                  
    xlabel('Tube radius, $R$ [cm]', 'interpreter','latex', 'fontsize',12)
    xticks(0:0.25:RADIUSi*100)
    xtickformat('%.2f')
    ylabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',12)
    ylim([0, LENGTH+0.5])
    yticks(0:1:LENGTH)
    zlabel('H$_2$ mole fraction, $y_{H2}$ [$\%$]', 'interpreter','latex', 'fontsize',12)
    ztickformat('%.0f')
    filename = 'MoleFractionProfileH2';        
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
  case 5 % H2O molefraction
    surf(r*100,z,y(:,:,5)*100)
    view(az, el);                              
    xlabel('Tube radius, $R$ [cm]', 'interpreter','latex', 'fontsize',12)
    xticks(0:0.25:RADIUSi*100)
    xtickformat('%.2f')
    ylabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',12)
    ylim([0, LENGTH+0.5])
    yticks(0:1:LENGTH)
    zlabel('H$_2$O mole fraction, $y_{H2O}$ [$\%$]', 'interpreter','latex', 'fontsize',12)
    ztickformat('%.0f')
    filename = 'MoleFractionProfileH2O';           
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
  case 6 % N2 molefraction
    surf(r*100,z,y(:,:,6)*100)
    view(az, el);                                
    xlabel('Tube radius, $R$ [cm]', 'interpreter','latex', 'fontsize',12)
    xticks(0:0.25:RADIUSi*100)
    xtickformat('%.2f')
    ylabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',12)
    ylim([0, LENGTH+0.5])
    yticks(0:1:LENGTH)
    zlabel('N$_2$ mole fraction, $y_{N2}$ [$\%$]', 'interpreter','latex', 'fontsize',12)
    ztickformat('%.3f')
    filename = 'MoleFractionProfileN2';          
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
    case 7 % MWg
    surf(r*100,z,MWg)
    view(az, el);                                
    xlabel('Tube radius, $R$ [cm]', 'interpreter','latex', 'fontsize',12)
    xticks(0:0.25:RADIUSi*100)
    xtickformat('%.2f')
    ylabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',12)
    ylim([0, LENGTH+0.5])
    yticks(0:1:LENGTH)
    zlabel('Molar mass, $MWg$ [$kg/kmol$]', 'interpreter','latex', 'fontsize',12)
    zlim([min(MWg(:,1)) 18])
    ztickformat('%.1f')
    filename = 'MWg';          
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
  case 8 % Component mole fractions
    figure
    hold on
    plot(z, y(:,1,1)*100, ':', 'color','#A2142F', 'LineWidth',2)
    plot(z, y(:,1,2)*100, ':', 'color','#D95319', 'LineWidth',2)
    plot(z, y(:,1,3)*100, ':', 'color','#EDB120', 'LineWidth',2)
    plot(z, y(:,1,4)*100, ':', 'color','#7E2F8E', 'LineWidth',2)
    plot(z, y(:,1,5)*100, ':', 'color','#77AC30', 'LineWidth',2)
    plot(z, y(:,1,6)*100, ':', 'color','#0072BD', 'LineWidth',2)
    lgd = legend('~~CH$_4$ mole fraction, $y_{CH_4}$~~~~', '~~CO mole fraction, $y_{CO}$~~~~',...
        '~~CO$_2$ mole fraction, $y_{CO_2}$~~~~', '~~H$_2$ mole fraction, $y_{H_2}$~~~~',...
        '~~H$_2$O mole fraction, $y_{H_2O}$~~~~', '~~N$_2$ mole fraction, $y_{N_2}$~~~~',...
        'interpreter','latex', 'location','northoutside', ...
        'Orientation','horizontal', 'Box','off', 'fontsize',10);
    lgd.NumColumns = 2;
    xlabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',12)
    ylabel('Mole fraction, $y_i$ [\%]', 'interpreter', 'latex', 'fontsize', 12)
    ylim([0 80])
    filename = 'Molefractions';           
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
  case 9 % Effectiveness factor (eta)
    plot(z, eta(:,1), 'LineWidth', 2);
    xlabel('Reactor length, $z$ [m]', 'interpreter', 'latex', 'fontsize',12)
    ylabel('Effectiveness factor, $\eta$ [$-$]', 'interpreter', 'latex', 'fontsize',12)
    ytickformat('%.2f')
    filename = 'Effectiveness';
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
  case 10 % Reaction rate (Rrxn)
    surf(r*100,z,Rrxn)
    view(az, el);                                
    xlabel('Tube radius, $R$ [cm]', 'interpreter','latex', 'fontsize',12)
    xticks(0:0.25:RADIUSi*100)
    xtickformat('%.2f')
    ylabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',12)
    ylim([0, LENGTH+0.5])
    yticks(0:1:LENGTH)
    zlabel('Reaction rate, $R_{CH4}$ [$kmol/m^3_{bulk}/s$]', 'interpreter','latex', 'fontsize',12)
    ztickformat('%.2f')
    filename = 'Reactionrate';          
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
  case 11 % Superficial velocity (uz)
    surf(r*100,z,uz)
    view(az, el);                                  
    xlabel('Tube radius, $R$ [cm]', 'interpreter','latex', 'fontsize',12)
    xticks(0:0.25:RADIUSi*100)
    xtickformat('%.2f')
    ylabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',12)
    ylim([0, LENGTH+0.5])
    yticks(0:1:LENGTH)
    zlabel('Superficial velocity, $u_z$ [m/s]', 'interpreter','latex', 'fontsize',12)
    ztickformat('%.2f')
    filename = 'SuperficialVelocity';              
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
  case 12 % Temperature (T)
    surf(r*100,z,T-273.15)
    view(az, el);                                 
    xlabel('Tube radius, $R$ [cm]', 'interpreter','latex', 'fontsize',12)
    xticks(0:0.25:RADIUSi*100)
    xtickformat('%.2f')
    ylabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',12)
    ylim([0, LENGTH+0.5])
    yticks(0:1:LENGTH)
    zlabel('Temperature, $T$ [$^\circ$C]', 'interpreter','latex', 'fontsize',12)
    ztickformat('%.0f')
    filename = 'Temperature';                      
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
  case 13 % Pressure (P)
    plot(z,p/100000, 'LineWidth', 2);
    xlabel('Reactor length, $z$ [m]', 'interpreter', 'latex', 'fontsize',12)
    ylabel('Pressure, $p$ [bar]', 'interpreter', 'latex', 'fontsize',12)
    ytickformat('%.2f')
    filename = 'Pressure';
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
  case 14 % Heat flow (Q)
    plot(z, Q/1000, 'LineWidth', 2);
    xlabel('Reactor length, $z$ [m]', 'interpreter', 'latex', 'fontsize',12)
    ylabel('Heat flow, $Q$ [kW]', 'interpreter', 'latex', 'fontsize',12)
    ytickformat('%.0f')
    filename = 'Heatflow';
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
  case 15 % Mass/Molar/Volumetric flowrate [kmol/h - kg/h - m3/h]
    figure
    subplot(3,1,1)
    plot(z, MassFlow(:,1), ':', 'color','#7E2F8E', 'LineWidth',2)
    legend('Mass flowrate, $\phi_m$',...
        'interpreter','latex', 'location','northeast', ...
        'Orientation','horizontal', 'Box','off', 'fontsize',10);
    ytickformat('%.1f')
    hold on
    subplot(3,1,2)
    plot(z, MolarFlow(:,1), ':', 'color','#A2142F', 'LineWidth',2)
    legend('Molar flowrate, $\phi_M$',...
        'interpreter','latex', 'location','northeast', ...
        'Orientation','horizontal', 'Box','off', 'fontsize',10);
    ytickformat('%.1f')
    hold on
    subplot(3,1,3)
    plot(z, VolumetricFlow(:,1), ':', 'color','#0072BD', 'LineWidth',2)
    legend('Volumetric flowrate, $\phi_v$',...
        'interpreter','latex', 'location','northeast', ...
        'Orientation','horizontal', 'Box','off', 'fontsize',10);
    xlabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',12)
    ytickformat('%.1f')
    filename = 'Flowrates';           
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
    
  case 0 % all plots below
   figure % molefractions
    hold on
    plot(z, y(:,1,1)*100, ':', 'color','#A2142F', 'LineWidth',2)
    plot(z, y(:,1,2)*100, ':', 'color','#D95319', 'LineWidth',2)
    plot(z, y(:,1,3)*100, ':', 'color','#EDB120', 'LineWidth',2)
    plot(z, y(:,1,4)*100, ':', 'color','#7E2F8E', 'LineWidth',2)
    plot(z, y(:,1,5)*100, ':', 'color','#77AC30', 'LineWidth',2)
    plot(z, y(:,1,6)*100, ':', 'color','#0072BD', 'LineWidth',2)
    lgd = legend('~~CH$_4$ mole fraction, $y_{CH_4}$~~~~', '~~CO mole fraction, $y_{CO}$~~~~',...
        '~~CO$_2$ mole fraction, $y_{CO_2}$~~~~', '~~H$_2$ mole fraction, $y_{H_2}$~~~~',...
        '~~H$_2$O mole fraction, $y_{H_2O}$~~~~', '~~N$_2$ mole fraction, $y_{N_2}$~~~~',...
        'interpreter','latex', 'location','northoutside', ...
        'Orientation','horizontal', 'Box','off', 'fontsize',10);
    lgd.NumColumns = 2;
    xlabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',10)
    ylabel('Mole fraction, $y_i$ [\%]', 'interpreter', 'latex', 'fontsize', 10)
    xtickformat('%.1f')
    ylim([0 80])
    filename = 'Molefractions';           
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',10);
    saveas(gca, fullfile(fname, filename), 'png');
   figure % Effectiveness factor
    plot(z, eta(:,1), 'LineWidth', 2);
    xlabel('Reactor length, $z$ [m]', 'interpreter', 'latex', 'fontsize',12)
    ylabel('Effectiveness factor, $\eta$ [$-$]', 'interpreter', 'latex', 'fontsize',12)
    ytickformat('%.2f')
    xtickformat('%.1f')
    filename = 'Effectiveness';
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
   figure % Reaction rate
    surf(r*100,z,Rrxn) 
    view(az, el);                                
    xlabel('Tube radius, $R$ [cm]', 'interpreter','latex', 'fontsize',10)
    xticks(0:0.6:RADIUSi*100)
    xtickformat('%.2f')
    ytickformat('%.1f')
    ylabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',10)
    ylim([0, LENGTH+0.3])
    yticks(0:0.5:LENGTH)
    zlabel('Reaction rate, $R_{CH4}$ [$kmol/m^3_{bulk}/s$]', 'interpreter','latex', 'fontsize',10)
    ztickformat('%.2f')
    filename = 'Reactionrate';          
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',10);
    saveas(gca, fullfile(fname, filename), 'png');
   figure % uz
    surf(r*100,z,uz)
    view(az, el);                                 
    xlabel('Tube radius, $R$ [cm]', 'interpreter','latex', 'fontsize',10)
    xticks(0:0.6:RADIUSi*100)
    xtickformat('%.2f')
    ytickformat('%.1f')
    ylabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',10)
    ylim([0, LENGTH+0.3])
    yticks(0:0.5:LENGTH)
    zlabel('Superficial velocity, $u_z$ [m/s]', 'interpreter','latex', 'fontsize',10)
    ztickformat('%.2f')
    filename = 'SuperficialVelocity';             
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',10);
    saveas(gca, fullfile(fname, filename), 'png');
   figure % T
    surf(r*100,z,T-273.15)
    view(az, el);                                
    xlabel('Tube radius, $R$ [cm]', 'interpreter','latex', 'fontsize',10)
    xticks(0:0.6:RADIUSi*100)
    xtickformat('%.2f')
    ytickformat('%.1f')
    ylabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',10)
    ylim([0, LENGTH+0.3])
    yticks(0:0.5:LENGTH)
    zlabel('Temperature, $T$ [$^\circ$C]', 'interpreter','latex', 'fontsize',10)
    ztickformat('%.0f')
    filename = 'Temperature';               
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',10);
    saveas(gca, fullfile(fname, filename), 'png');
   figure % P
    plot(z,p/100000, 'LineWidth', 2);
    xlabel('Reactor length, $z$ [m]', 'interpreter', 'latex', 'fontsize',12)
    ylabel('Pressure, $p$ [bar]', 'interpreter', 'latex', 'fontsize',12)
    ytickformat('%.2f')
    xtickformat('%.1f')
    filename = 'Pressure';
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
   figure % Q
    plot(z, Q/1000, 'LineWidth', 2);
    xlabel('Reactor length, $z$ [m]', 'interpreter', 'latex', 'fontsize',12)
    ylabel('Heat flow, $Q$ [kW]', 'interpreter', 'latex', 'fontsize',12)
    ytickformat('%.0f')
    xtickformat('%.1f')
    filename = 'Heatflow';
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',12);
    saveas(gca, fullfile(fname, filename), 'png');
   figure % flowrates
    subplot(3,1,1)
    plot(z, MassFlow(:,1), ':', 'color','#7E2F8E', 'LineWidth',2)
    legend('Mass flowrate, $\phi_m$',...
        'interpreter','latex', 'location','northeast', ...
        'Orientation','horizontal', 'Box','off', 'fontsize',11);
    ytickformat('%.2f')
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',10);
    hold on
    subplot(3,1,2)
    plot(z, MolarFlow(:,1), ':', 'color','#A2142F', 'LineWidth',2)
    legend('Molar flowrate, $\phi_M$',...
        'interpreter','latex', 'location','northeast', ...
        'Orientation','horizontal', 'Box','off', 'fontsize',11);
    ytickformat('%.0f')
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',10);
    hold on
    subplot(3,1,3)
    plot(z, VolumetricFlow(:,1), ':', 'color','#0072BD', 'LineWidth',2)
    legend('Volumetric flowrate, $\phi_v$',...
        'interpreter','latex', 'location','northeast', ...
        'Orientation','horizontal', 'Box','off', 'fontsize',11);
    xlabel('Reactor length, $L$ [m]', 'interpreter','latex', 'fontsize',12)
    ytickformat('%.0f')
    filename = 'Flowrates';           
    fname = 'C:\Users\Sander Wijnsma\OneDrive - NTNU\Master\Courses S4\MATLAB\Methanation\Profiles';
    set(gca, 'TickLabelInterpreter','latex', 'fontsize',10);
    saveas(gca, fullfile(fname, filename), 'png');
        
end %switch
